package com.jiuqi.dna.ide.designer.parts;

import com.jiuqi.dna.ide.designer.connection.IConnectionAnchorProvider;
import com.jiuqi.dna.ide.designer.connection.IConnectionProvider;
import com.jiuqi.dna.ide.designer.elements.ICompositeElement;
import com.jiuqi.dna.ide.designer.elements.IDesignerDiagramElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import com.jiuqi.dna.ide.designer.elements.IRootElement;
import com.jiuqi.dna.ide.designer.figure.IFigureProvider;
import com.jiuqi.dna.ide.designer.policies.ILayoutEditPolicyProvider;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;

/* loaded from: com_jiuqi_dna_ide_designer_parts.jar:com/jiuqi/dna/ide/designer/parts/DesignerEditPartFactory.class */
public class DesignerEditPartFactory implements EditPartFactory {
    private IFigureProvider figureProvider;
    private IConnectionAnchorProvider connectionAnchorProvider;
    private IConnectionProvider connectionProvider;
    private ILayoutEditPolicyProvider layoutEditPolicyProvider;

    public EditPart createEditPart(EditPart context, Object model) {
        EditPart part = getPartForElement(model);
        part.setModel(model);
        return part;
    }

    private EditPart getPartForElement(Object model) {
        if (model instanceof IDesignerDiagramElement) {
            return new DesignerDiagramEditPart();
        }
        if (model instanceof IRootElement) {
            DesignerRootEditPart editpart = new DesignerRootEditPart();
            editpart.setFigureProvider(this.figureProvider);
            editpart.setLayoutEditPolicyProvider(this.layoutEditPolicyProvider);
            return editpart;
        }
        if (model instanceof ICompositeElement) {
            CompositeEditPart editpart2 = new CompositeEditPart();
            editpart2.setFigureProvider(this.figureProvider);
            editpart2.setConnectionAnchorProvider(this.connectionAnchorProvider);
            editpart2.setLayoutEditPolicyProvider(this.layoutEditPolicyProvider);
            return editpart2;
        }
        if (model instanceof IFigureElement) {
            FigureEditPart editpart3 = new FigureEditPart();
            editpart3.setFigureProvider(this.figureProvider);
            editpart3.setConnectionAnchorProvider(this.connectionAnchorProvider);
            return editpart3;
        }
        if (model instanceof ILinkElement) {
            LinkEditPart editpart4 = new LinkEditPart();
            editpart4.setConnectionProvider(this.connectionProvider);
            return editpart4;
        }
        throw new RuntimeException("Can't create part for model element: " + (model != null ? model.getClass().getName() : "null"));
    }

    public void setFigureProvider(IFigureProvider figureProvider) {
        this.figureProvider = figureProvider;
    }

    public void setConnectionAnchorProvider(IConnectionAnchorProvider connectionAnchorProvider) {
        this.connectionAnchorProvider = connectionAnchorProvider;
    }

    public void setConnectionProvider(IConnectionProvider connectionProvider) {
        this.connectionProvider = connectionProvider;
    }

    public void setLayoutEditPolicyProvider(ILayoutEditPolicyProvider layoutEditPolicyProvider) {
        this.layoutEditPolicyProvider = layoutEditPolicyProvider;
    }
}
